OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Egutegia",
    "Hello," : "Kaixo,",
    "Individual" : "Bakarkakoa",
    "Group" : "Taldea",
    "Unknown" : "Ezezaguna",
    "Optional" : "Aukerakoa",
    "{name} ({email})" : "{name} ({email})",
    "Please create a calendar first." : "Aurretik, egutegi bat sortu, mesedez.",
    "New event" : "Sarrera berria",
    "group" : "taldea",
    "Attendees" : "Partaideak",
    "Reminders" : "Oroigarriak",
    "Repeating" : "Errepikapena",
    "Confirmed" : "Baieztatua",
    "Cancelled" : "Ezeztatua",
    "Global" : "Globala",
    "None" : "Ezer",
    "Every day" : "Egunero",
    "never" : "inoiz",
    "5 minutes before" : "5 minutu lehenago",
    "10 minutes before" : "10 minutu lehenago",
    "15 minutes before" : "15 minutu lehenago",
    "30 minutes before" : "30 minutu lehenago",
    "1 hour before" : "Ordu 1 lehenago",
    "2 hours before" : "2 ordu lehenago",
    "Audio" : "Audio",
    "min" : "min",
    "hours" : "ordu",
    "days" : "egun",
    "week" : "aste",
    "before" : "lehenago",
    "start" : "Hasi",
    "end" : "bukatu",
    "Week {number} of {year}" : "{year}ko {number} astea",
    "Title of the Event" : "Gertaeraren izenburua",
    "All day Event" : "Egun osoko gertaera",
    "Delete" : "Ezabatu",
    "Cancel" : "Ezeztatu",
    "More ..." : "Gehiago ...",
    "Create" : "Sortu",
    "Update" : "Eguneratu",
    "Close" : "Itxi",
    "Location" : "Kokapena",
    "Description" : "Deskribapena",
    "Export" : "Esportatu",
    "Day" : "Eguna",
    "Week" : "Astea",
    "Month" : "Hilabetea",
    "Today" : "Gaur",
    "Share Calendar" : "Elkarbanatu egutegia",
    "Shared" : "Elkarbanatuta",
    "More" : "Gehiago",
    "Edit" : "Editatu",
    "Link" : "Esteka",
    "Download" : "Deskargatu",
    "can edit" : "editatu dezake",
    "Send" : "Bidali",
    "New Calendar" : "Egutegi berria",
    "Name" : "Izena",
    "Edit event" : "Editatu gertaera",
    "Time" : "Noiz",
    "Type" : "Mota",
    "Repeat" : "Errepikatu",
    "Add" : "Gehitu",
    "from" : "lekua",
    "to" : "Noiz arte",
    "Import Calendars" : "Egutegiak Inportatu",
    "New calendar" : "Egutegi berria",
    "File is empty" : "Fitxategia hutsik dago",
    "Import calendar" : "Egutegia inportatu",
    "Primary CalDAV address" : "CalDAV helbide nagusia",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV helbidea"
},
"nplurals=2; plural=(n != 1);");
